# eric7.MicroPython.Devices

Package containing the device interface modules and device specific dialogs.

### Packages

CircuitPythonUpdater | Package implementing the updater and associated dialogs.
EspDialogs | Package implementing dialogs used by the EspDevices module.

### Modules

CircuitPythonDevices | Module implementing the device interface class for CircuitPython boards.
DeviceBase | Module implementing some utility functions and the MicroPythonDevice base class.
EspDevices | Module implementing the device interface class for ESP32 and ESP8266 based boards.
GenericMicroPythonDevices | Module implementing the device interface class for generic MicroPython devices (i.e.
MicrobitDevices | Module implementing the device interface class for BBC micro:bit and Calliope mini boards.
PyBoardDevices | Module implementing the device interface class for PyBoard boards.
RP2040Devices | Module implementing the device interface class for RP2040 based boards (e.g.
TeensyDevices | Module implementing the device interface class for Teensy boards with MicroPython.
Devices | Package containing the device interface modules and device specific dialogs.